@@ -9,7 +9,7 @@ from flyingsphinx import API, __version__
 @fudge.patch('requests.get')
 def test_get(get_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
 
   get_method.expects_call().with_args(
     'https://flying-sphinx.com/api/my/app/path',
@@ -26,7 +26,7 @@ def test_get(get_method):
 @fudge.patch('requests.get')
 def test_get_response(get_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
   get_method.is_callable().calls(lambda uri, **kwargs: response)
 
   api = API('abc', '123')
@@ -36,7 +36,7 @@ def test_get_response(get_method):
 @fudge.patch('requests.post')
 def test_post(post_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
 
   post_method.expects_call().with_args(
     'https://flying-sphinx.com/api/my/app/start', {}, headers = {
@@ -52,7 +52,7 @@ def test_post(post_method):
 @fudge.patch('requests.post')
 def test_post_response(post_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
   post_method.is_callable().calls(lambda uri, params, **kwargs: response)
 
   api = API('abc', '123')
@@ -62,7 +62,7 @@ def test_post_response(post_method):
 @fudge.patch('requests.put')
 def test_put(put_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
 
   put_method.expects_call().with_args(
     'https://flying-sphinx.com/api/my/app/path', {'foo': 'bar'}, headers = {
@@ -78,7 +78,7 @@ def test_put(put_method):
 @fudge.patch('requests.put')
 def test_put_response(put_method):
   response = fudge.Fake('Response')
-  response.json = {'qux': 'quux'}
+  response.provides('json').returns({'qux': 'quux'})
   put_method.is_callable().calls(lambda uri, params, **kwargs: response)
 
   api = API('abc', '123')
